@@ -56,6 +56,7 @@ struct _GnomeThemeCommonInfo
   gchar *name;
   gchar *readable_name;
   gint priority;
+  gboolean hidden;
 };
 
 typedef struct _GnomeThemeInfo GnomeThemeInfo;
@@ -66,6 +67,7 @@ struct _GnomeThemeInfo
   gchar *name;
   gchar *readable_name;
   gint priority;
+  gboolean hidden;
 
   guint has_gtk : 1;
   guint has_keybinding : 1;
@@ -79,6 +81,7 @@ struct _GnomeThemeCursorInfo {
   gchar *name;
   gchar *readable_name;
   gint priority;
+  gboolean hidden;
 
   GArray *sizes;
   GdkPixbuf *thumbnail;
@@ -92,6 +95,7 @@ struct _GnomeThemeMetaInfo
   gchar *name;
   gchar *readable_name;
   gint priority;
+  gboolean hidden;
 
   gchar *comment;
   gchar *icon_file;
@@ -127,6 +131,7 @@ enum {
 
 typedef void (* ThemeChangedCallback) (GnomeThemeCommonInfo *theme,
 				       GnomeThemeChangeType  change_type,
+                                       GnomeThemeElement     element_type,
 				       gpointer              user_data);
 
 #define GNOME_THEME_ERROR gnome_theme_info_error_quark ()
