@@ -316,39 +316,65 @@ left_handed_to_gconf (GConfPropertyEditor *peditor,
 }
 
 static void
-scrollmethod_radio_button_release_event (GtkWidget *widget,
-					 GdkEventButton *event,
-					 GtkBuilder *dialog)
+scrollmethod_changed_event (GConfPropertyEditor *peditor,
+			    const gchar *key,
+			    const GConfValue *value,
+			    GtkBuilder *dialog)
 {
+	GtkToggleButton *disabled = GTK_TOGGLE_BUTTON (WID ("scroll_disabled_radio"));
+
 	gtk_widget_set_sensitive (WID ("horiz_scroll_toggle"),
-				  (widget != WID ("scroll_disabled_radio")));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
+				  !gtk_toggle_button_get_active (disabled));
 }
 
-static GConfValue *
-scroll_method_from_gconf (GConfPropertyEditor *peditor,
-			  const GConfValue *value)
+static void
+synaptics_check_capabilities (GtkBuilder *dialog)
 {
-	GConfValue *new_value;
+#ifdef HAVE_XINPUT
+	int numdevices, i;
+	XDeviceInfo *devicelist;
+	Atom realtype, prop;
+	int realformat;
+	unsigned long nitems, bytes_after;
+	unsigned char *data;
 
-	new_value = gconf_value_new (GCONF_VALUE_INT);
+	prop = XInternAtom (GDK_DISPLAY (), "Synaptics Capabilities", True);
+	if (!prop)
+		return;
 
-	gconf_value_set_int (new_value, gconf_value_get_int (value));
+	devicelist = XListInputDevices (GDK_DISPLAY (), &numdevices);
+	for (i = 0; i < numdevices; i++) {
+		if (devicelist[i].use != IsXExtensionPointer)
+			continue;
 
-	return new_value;
-}
+		gdk_error_trap_push ();
+		XDevice *device = XOpenDevice (GDK_DISPLAY (),
+					       devicelist[i].id);
+		if (gdk_error_trap_pop ())
+			continue;
 
-static GConfValue *
-scroll_method_to_gconf (GConfPropertyEditor *peditor,
-		        const GConfValue *value)
-{
-	GConfValue *new_value;
+		gdk_error_trap_push ();
+		if ((XGetDeviceProperty (GDK_DISPLAY (), device, prop, 0, 2, False,
+					 XA_INTEGER, &realtype, &realformat, &nitems,
+					 &bytes_after, &data) == Success) && (realtype != None)) {
+			/* Property data is booleans for has_left, has_middle,
+			 * has_right, has_double, has_triple */
+			if (!data[0] || !data[1] || !data[2]) {
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("tap_to_click_toggle")), TRUE);
+				gtk_widget_set_sensitive (WID ("tap_to_click_toggle"), FALSE);
+			}
 
-	new_value = gconf_value_new (GCONF_VALUE_INT);
+			if (!data[3])
+				gtk_widget_set_sensitive (WID ("scroll_twofinger_radio"), FALSE);
 
-	gconf_value_set_int (new_value, gconf_value_get_int (value));
+			XFree (data);
+		}
+		gdk_error_trap_pop ();
 
-	return new_value;
+		XCloseDevice (GDK_DISPLAY (), device);
+	}
+	XFreeDeviceList (devicelist);
+#endif
 }
 
 static gboolean
@@ -422,6 +448,7 @@ setup_dialog (GtkBuilder *dialog, GConfChangeSet *changeset)
 		 "conv-to-widget-cb", left_handed_from_gconf,
 		 "conv-from-widget-cb", left_handed_to_gconf,
 		 NULL);
+	/* explicitly connect to button-release so that you can change orientation with either button */
 	g_signal_connect (WID ("right_handed_radio"), "button_release_event",
 		G_CALLBACK (orientation_radio_button_release_event), NULL);
 	g_signal_connect (WID ("left_handed_radio"), "button_release_event",
@@ -463,24 +490,21 @@ setup_dialog (GtkBuilder *dialog, GConfChangeSet *changeset)
 	if (find_synaptics () == FALSE)
 		gtk_notebook_remove_page (GTK_NOTEBOOK (WID ("prefs_widget")), -1);
 	else {
-		peditor = gconf_peditor_new_boolean
+		gconf_peditor_new_boolean
 			(changeset, "/desktop/gnome/peripherals/touchpad/disable_while_typing", WID ("disable_w_typing_toggle"), NULL);
-		peditor = gconf_peditor_new_boolean
+		gconf_peditor_new_boolean
 			(changeset, "/desktop/gnome/peripherals/touchpad/tap_to_click", WID ("tap_to_click_toggle"), NULL);
-		peditor = gconf_peditor_new_boolean
+		gconf_peditor_new_boolean
 			(changeset, "/desktop/gnome/peripherals/touchpad/horiz_scroll_enabled", WID ("horiz_scroll_toggle"), NULL);
 		radio = GTK_RADIO_BUTTON (WID ("scroll_disabled_radio"));
 		peditor = gconf_peditor_new_select_radio
 			(changeset, "/desktop/gnome/peripherals/touchpad/scroll_method", gtk_radio_button_get_group (radio),
-			 "conv-to-widget-cb", scroll_method_from_gconf,
-			 "conv-from-widget-cb", scroll_method_to_gconf,
 			 NULL);
-			 g_signal_connect (WID ("scroll_disabled_radio"), "button_release_event",
-				 G_CALLBACK (scrollmethod_radio_button_release_event), dialog);
-			 g_signal_connect (WID ("scroll_edge_radio"), "button_release_event",
-				 G_CALLBACK (scrollmethod_radio_button_release_event), dialog);
-			 g_signal_connect (WID ("scroll_twofinger_radio"), "button_release_event",
-				 G_CALLBACK (scrollmethod_radio_button_release_event), dialog);
+
+		synaptics_check_capabilities (dialog);
+		scrollmethod_changed_event (GCONF_PROPERTY_EDITOR (peditor), NULL, NULL, dialog);
+		g_signal_connect (peditor, "value-changed",
+				  G_CALLBACK (scrollmethod_changed_event), dialog);
 	}
 
 }
@@ -492,7 +516,7 @@ create_dialog (void)
 {
 	GtkBuilder   *dialog;
 	GtkSizeGroup *size_group;
-	GError       *error = NULL;   
+	GError       *error = NULL;
 
 	dialog = gtk_builder_new ();
 	gtk_builder_add_from_file (dialog, GNOMECC_UI_DIR "/gnome-mouse-properties.ui", &error);
@@ -571,13 +595,14 @@ main (int argc, char **argv)
 	context = g_option_context_new (_("- GNOME Mouse Preferences"));
 	g_option_context_add_main_entries (context, cap_options, GETTEXT_PACKAGE);
 	capplet_init (context, &argc, &argv);
-	
+
 	capplet_init_stock_icons ();
 
 	activate_settings_daemon ();
 
 	client = gconf_client_get_default ();
 	gconf_client_add_dir (client, "/desktop/gnome/peripherals/mouse", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+	gconf_client_add_dir (client, "/desktop/gnome/peripherals/touchpad", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 
 	dialog = create_dialog ();
 
